@@ -6,7 +6,7 @@
 #      *                                                                *
 #      ******************************************************************
 
-from DPiNetwork import DPiNetwork
+from dpeaDPi.DPiNetwork import DPiNetwork
 dpiNetwork = DPiNetwork()
 
 
