@@ -124,7 +124,7 @@
 
 from array import *
 from time import sleep
-from DPiNetwork import DPiNetwork
+from dpeaDPi.DPiNetwork import DPiNetwork
 dpiNetwork = DPiNetwork()
 
 #
